@@ -1,8 +1,8 @@
 from __future__ import annotations
 
-from collections.abc import Callable
 from typing import (
     Any,
+    Callable,
     Coroutine,
     TypeVar,
 )
